>From 6cc9b0be57276b209069da459e167114c04a4e00 Mon Sep 17 00:00:00 2001
From: Takashi Iwai <tiwai@suse.de>
Date: Thu, 25 Mar 2021 08:31:23 +0100
Subject: [PATCH v3 3/6] ALSA: core: Use inline for dummy snd_power_*() helpers

Using the do-while(0) isn't really suitable for a macro with an
argument, as checkpatch recently complained.  Replace with static
inline functions for safety.

Signed-off-by: Takashi Iwai <tiwai@suse.de>
---
 include/sound/core.h | 16 +++++++++++++---
 1 file changed, 13 insertions(+), 3 deletions(-)

diff --git a/include/sound/core.h b/include/sound/core.h
index b915285a2b4e..d82ecca4c99a 100644
--- a/include/sound/core.h
+++ b/include/sound/core.h
@@ -156,9 +156,19 @@ int snd_power_wait(struct snd_card *card, unsigned int power_state);
 
 #else /* ! CONFIG_PM */
 
-static inline int snd_power_wait(struct snd_card *card, unsigned int state) { return 0; }
-#define snd_power_get_state(card)	({ (void)(card); SNDRV_CTL_POWER_D0; })
-#define snd_power_change_state(card, state)	do { (void)(card); } while (0)
+static inline int snd_power_wait(struct snd_card *card, unsigned int state)
+{
+	return 0;
+}
+
+static inline unsigned int snd_power_get_state(struct snd_card *card)
+{
+	return SNDRV_CTL_POWER_D0;
+}
+
+static inline void snd_power_change_state(struct snd_card *card, unsigned int state)
+{
+}
 
 #endif /* CONFIG_PM */
 
-- 
2.26.2

